.. _api_meshing_trimesh:

.. currentmodule:: microstructpy.meshing

microstructpy.meshing.TriMesh
=============================

.. autoclass:: TriMesh
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
